@@ -12,8 +12,9 @@ from .pattern_detectors.do_all_detector import run_detection as detect_do_all, D
 from .pattern_detectors.geometric_decomposition_detector import run_detection as detect_gd, GDInfo
 from .pattern_detectors.pipeline_detector import run_detection as detect_pipeline, PipelineInfo
 from .pattern_detectors.reduction_detector import run_detection as detect_reduction, ReductionInfo
-from discopop_explorer.pattern_detectors.task_parallelism.task_parallelism_detector import build_preprocessed_graph_and_run_detection \
-    as detect_tp
+from discopop_explorer.pattern_detectors.task_parallelism.task_parallelism_detector import (
+    build_preprocessed_graph_and_run_detection as detect_tp,
+)
 from .pattern_detectors.PatternInfo import PatternInfo
 
 
@@ -28,7 +29,9 @@ class DetectionResult(object):
         pass
 
     def __str__(self):
-        return '\n\n\n'.join(["\n\n".join([str(v2) for v2 in v]) for v in self.__dict__.values() if v])
+        return "\n\n\n".join(
+            ["\n\n".join([str(v2) for v2 in v]) for v in self.__dict__.values() if v]
+        )
 
 
 class PatternDetectorX(object):
@@ -59,31 +62,39 @@ class PatternDetectorX(object):
         for n in dummies_to_remove:
             self.pet.g.remove_node(n)
 
-    def detect_patterns(self, cu_dict, dependencies, loop_data, reduction_vars, file_mapping, cu_inst_result_file,
-                        llvm_cxxfilt_path, discopop_build_path, enable_task_pattern):
-        """Runs pattern discovery on the CU graph
-        """
+    def detect_patterns(
+        self,
+        cu_dict,
+        dependencies,
+        loop_data,
+        reduction_vars,
+        file_mapping,
+        cu_inst_result_file,
+        llvm_cxxfilt_path,
+        discopop_build_path,
+        enable_task_pattern,
+    ):
+        """Runs pattern discovery on the CU graph"""
         self.__merge(False, True)
 
         res = DetectionResult()
 
         # reduction before doall!
-        # t1 = time.time()
         res.reduction = detect_reduction(self.pet)
-        # t2 = time.time()
-        # print(f"reduction detection: {t2-t1}")
         res.do_all = detect_do_all(self.pet)
-        # t3 = time.time()
-        # print(f"do_all detection: {t3-t2}")
         res.pipeline = detect_pipeline(self.pet)
-        # t4 = time.time()
-        # print(f"pipeline detection: {t4-t3}")
         res.geometric_decomposition = detect_gd(self.pet)
-        # t5 = time.time()
-        # print(f"geometric_decomposition detection: {t5-t4}")
 
         # check if task pattern should be enabled
         if enable_task_pattern:
-            res.task = detect_tp(cu_dict, dependencies, loop_data, reduction_vars, file_mapping, cu_inst_result_file,
-                                 llvm_cxxfilt_path, discopop_build_path)
+            res.task = detect_tp(
+                cu_dict,
+                dependencies,
+                loop_data,
+                reduction_vars,
+                file_mapping,
+                cu_inst_result_file,
+                llvm_cxxfilt_path,
+                discopop_build_path,
+            )
         return res
