@@ -14,8 +14,7 @@ import time
 
 
 class DoAllInfo(PatternInfo):
-    """Class, that contains do-all detection result
-    """
+    """Class, that contains do-all detection result"""
 
     def __init__(self, pet: PETGraphX, node: CUNode):
         """
@@ -31,18 +30,21 @@ class DoAllInfo(PatternInfo):
         self.reduction = r
 
     def __str__(self):
-        return f'Do-all at: {self.node_id}\n' \
-               f'Start line: {self.start_line}\n' \
-               f'End line: {self.end_line}\n' \
-               f'iterations: {self.iterations_count}\n' \
-               f'instructions: {self.instructions_count}\n' \
-               f'workload: {self.workload}\n' \
-               f'pragma: "#pragma omp parallel for"\n' \
-               f'private: {[v.name for v in self.private]}\n' \
-               f'shared: {[v.name for v in self.shared]}\n' \
-               f'first private: {[v.name for v in self.first_private]}\n' \
-               f'reduction: {[v.name for v in self.reduction]}\n' \
-               f'last private: {[v.name for v in self.last_private]}'
+        return (
+            f"Do-all at: {self.node_id}\n"
+            f"Start line: {self.start_line}\n"
+            f"End line: {self.end_line}\n"
+            # f"iterations: {self.iterations_count}\n"
+            # f"instructions: {self.instructions_count}\n"
+            # f"workload: {self.workload}\n"
+            f'pragma: "#pragma omp parallel for"\n'
+            f"private: {[v.name for v in self.private]}\n"
+            f"shared: {[v.name for v in self.shared]}\n"
+            f"first private: {[v.name for v in self.first_private]}\n"
+            f"reduction: {[v.name for v in self.reduction]}\n"
+            f"last private: {[v.name for v in self.last_private]}"
+        )
+
 
 def run_detection(pet: PETGraphX) -> List[DoAllInfo]:
     """Search for do-all loop pattern
@@ -50,34 +52,30 @@ def run_detection(pet: PETGraphX) -> List[DoAllInfo]:
     :param pet: PET graph
     :return: List of detected pattern info
     """
-    result : List[DoAllInfo] = []
-    for node in pet.all_nodes(NodeType.LOOP):        # t1 = time.time()
+    result: List[DoAllInfo] = []
+    for node in pet.all_nodes(NodeType.LOOP):
         if not contains(result, lambda x: x.node_id == node.id) and __detect_do_all(pet, node):
             node.do_all = True
             if not node.reduction and node.loop_iterations >= 0:
                 result.append(DoAllInfo(pet, node))
-        # t2 = time.time()
-        # print(f"ended Loop {node.start_line}: {t2 - t1} ")
 
     return result
 
 
-def __detect_do_all(pet: PETGraphX, root: CUNode) -> bool:
+def __detect_do_all(pet: PETGraphX, root_loop: CUNode) -> bool:
     """Calculate do-all value for node
 
     :param pet: PET graph
     :param root: root node
     :return: true if do-all
     """
-    subnodes = [pet.node_at(t)
-                for s, t, d in pet.out_edges(root.id, EdgeType.CHILD)]
+    subnodes = [pet.node_at(t) for s, t, d in pet.out_edges(root_loop.id, EdgeType.CHILD)]
 
     for i in range(0, len(subnodes)):
         children_cache: Dict[CUNode, List[CUNode]] = dict()
         dependency_cache: Dict[Tuple[CUNode, CUNode], Set[CUNode]] = dict()
         for j in range(i, len(subnodes)):
-            if pet.depends_ignore_readonly(subnodes[i], subnodes[j], root, children_cache=children_cache,
-                                           dep_cache=dependency_cache):
+            if pet.depends_ignore_readonly(subnodes[i], subnodes[j], root_loop):
                 return False
 
     return True
